module.exports = function (grunt) {

	var packageName = 'zh-rich-text';

	var libPath = 'src/lib/**/*.js';
	var configPath = 'src/config/**/*.js';
	var directivesPath = 'src/directives/**/*.js';
	var controllersPath = 'src/controllers/**/*.js';
	var registersPath = 'src/registers/**/*.js';
	var assetsPath = ['src/**/*.js'];
	var ignoredPath = ['!src/lib/**/*.js'];

	var testLibs = ["bower_components/angular-mocks/angular-mocks.js", "bower_components/q/q.js"];
  	var helperPath = 'tests/unit/specs/helpers/**/*.js';
  	var specsPath = 'tests/unit/specs/**/*spec*.js';
  	var mainZeedhi = 'bower_components/zeedhi-frontend/assets/dist/main.min.js';

	grunt.initConfig({
		jshint: {
			all: ['GruntFile.js', assetsPath, ignoredPath]
		},
		watch: {
			pivotal: {
				files: [assetsPath],
				tasks: ['jshint']
			}
		},
		bump: {
			options: {
				files: ['bower.json', 'package.json'],
				pushTo: 'origin',
				commitFiles: ["-a"],
				push: true
			}
		},
		concat: {
			zh: {
				options: {
					process: function (src, filepath) {
						return '\n' + '// FILE: ' + filepath + '\n' + src;
					}
				},
				src: [libPath, configPath, controllersPath, directivesPath, registersPath],
				dest: 'dist/' + packageName + '.js'
			},
			css: {
				options: {
					process: function (src, filepath) {
						return '\n' + '/* FILE: ' + filepath + '*/ \n' + src;
					}
				},
				src: ['src/lib/summernote.css', 'src/styles/' + packageName + '.css'],
				dest: 'dist/' + packageName + '.css'
			}
		},
		uglify: {
			options: {
				mangle: false
			},
			target: {
				files: {
					'dist/zh-rich-text.min.js': ['dist/' + packageName + '.js']
				}
			}
		},
		copy: {
			main: {
				files: [{
					expand: true,
					cwd: 'src/',
					src: 'templates/**/*',
					dest: 'dist/'
				}]
			}
		},
		jasmine: {
			pivotal: {
				src: ['dist/' + packageName + '.js'],
				options: {
					keepRunner: true,
					vendor: [mainZeedhi, testLibs],
					specs: specsPath,
					helpers: helperPath,
					template: require('grunt-template-jasmine-istanbul'),
					templateOptions: {
						coverage: 'bin/coverage/coverage.json',
						report: 'bin/coverage',
						thresholds: {
							lines: 0.0,
							statements: 0.0,
							branches: 0.0,
							functions: 0.0
						}
					}
				}
			},
			toCommit: {
				src: ['dist/' + packageName + '.js'],
				options: {
					vendor: [mainZeedhi, testLibs],
					specs: specsPath,
					helpers: helperPath
				}
			}
		},
		buildEnvironment: {
			development: {
				configFile: 'config/development.json'
			},
			deploy: {
				configFile: 'config/deploy.json'
			},
			srcFolders: ['./', 'tests/functional', 'example/mobile', 'json']
		}
	});

	grunt.loadNpmTasks('grunt-contrib-jshint');
	grunt.loadNpmTasks('grunt-contrib-watch');
	grunt.loadNpmTasks('grunt-contrib-concat');
	grunt.loadNpmTasks('grunt-contrib-copy');
	grunt.loadNpmTasks('grunt-contrib-uglify');
	grunt.loadNpmTasks('grunt-bump');
	grunt.loadNpmTasks('grunt-zh-environment-builder');	
	grunt.loadNpmTasks('grunt-contrib-jasmine');


	// Default task.
	grunt.registerTask('default', ['jshint', 'concat', 'uglify', 'copy']);
	grunt.registerTask('test', ['jshint', 'concat', 'jasmine:pivotal']);
};